@@ -270,7 +270,7 @@ swf_tag_lossless_output_detail(swf_tag_t *tag, unsigned long *length,
                             indices_len);
         old_buff_ref = bitstream_buffer(bs2, 0);
         old_size = bitstream_length(bs2);
-        compsize = old_size * 1.001 + 12; // 稀に増える事もあるので
+        compsize = old_size * 1.001 + 12; // increasing, rarely situation
         tmp_buff = malloc(compsize);
         result = compress2(tmp_buff, &compsize, old_buff_ref, old_size, swf->compress_level);
         if (result != Z_OK) {
@@ -307,7 +307,7 @@ swf_tag_lossless_output_detail(swf_tag_t *tag, unsigned long *length,
         }
         old_buff_ref = bitstream_buffer(bs2, 0);
         old_size = bitstream_length(bs2);
-        compsize = old_size * 1.001 + 12; // 稀に増える事もあるので
+        compsize = old_size * 1.001 + 12; // increasing, rarely situation
         tmp_buff = malloc(compsize);
         result = compress2(tmp_buff, &compsize, old_buff_ref, old_size, swf->compress_level);
         if (result != Z_OK) {
@@ -408,9 +408,9 @@ unsigned char *swf_tag_lossless_get_png_data(void *detail,
                                              swf_tag_t *tag) {
     swf_tag_lossless_detail_t *swf_tag_lossless = (swf_tag_lossless_detail_t *) detail;
     unsigned char *data = NULL;
-    *length = 0;
     void *index_data = NULL;
     void *image_data = NULL;
+    *length = 0;
     if (detail == NULL) {
         fprintf(stderr, "swf_tag_lossless_get_lossless_data: detail == NULL at line(%d)\n", __LINE__);
         return NULL;
